-- $Revision: 16896 $
TradeskillInfo.options = {};
TradeskillInfo.options.CheckBoxes = {
	-- Item Tooltip
	["Source"] = { index=1, tooltipText="Show source in tooltip", var="TooltipSource"},
	["Used in"] = { index=2, tooltipText="Show used in in tooltip", var="TooltipUsedIn"},
	["Usable by"] = { index=3, tooltipText="Show who can use an item", var="TooltipUsableBy"},
	-- Recipe Tooltip
	["Known by"] = { index=5, tooltipText="Show known by in recipe tooltip", var="TooltipKnownBy"},
	["Learnable by"] = { index=6, tooltipText="Show learnable by in recipe tooltip", var="TooltipLearnableBy"},
	["Will be learnable by"] = { index=7, tooltipText="Show will be learnable by in recipe tooltip", var="TooltipAvailableTo"},
	["ItemID"] = { index=9, tooltipText="Show ItemID in tooltip", var="TooltipID"},
	-- Tradeskill/Craft Frame
	["Skill required"] = { index=11, tooltipText="Show skill required", var="ShowSkillLevel"},
	["Combine cost"] = { index=12, tooltipText="Show combine cost", var="ShowSkillProfit"},
	-- Trainer
	["Trainer reagents"] = { index=15, tooltipText="Show recipe reagents in tooltip at trainer", var="TrainerReagents"},
	-- QuickSearch
	["Quick Search"] = { index=21, tooltipText="Enable Quick Search", var="QuickSearch"},
}
TradeskillInfo.options.ColorSwatches = {
	{ index=1, var="ColorSource" },
	{ index=2, var="ColorUsedIn" },
	{ index=3, var="ColorUsableBy" },
	{ index=5, var="ColorKnownBy" },
	{ index=6, var="ColorLearnableBy" },
	{ index=7, var="ColorAvailableTo" },
	{ index=9, var="ColorID" },
	{ index=15, var="ColorTrainerReagents" },
}
TradeskillInfo.options.Selections = {
	["Search Mouse Button"] = { index=1, tooltipText="Mouse button that does a quick search", table={"LeftButton","RightButton"}, var="SearchMouseButton" },
	["Search Shift Key"] = { index=2, tooltipText="Shift key to be held down for quick search", table={"Shift","Control","Alt"}, var="SearchShiftKey" },
}
TradeskillInfo.options.Frames = {
	["TradeskillInfo_Tab1"] = "TradeskillInfoConfig_Sub1Frame",
	["TradeskillInfo_Tab2"] = "TradeskillInfoConfig_Sub2Frame",
	["TradeskillInfo_Tab3"] = "TradeskillInfoConfig_Sub3Frame",
}

--	MoneyFormat = 3,
function TradeskillInfo:Config_Init()
	self:ToggleTab("TradeskillInfoConfig_Sub1Frame");
	if oSkin and oSkin.applySkin then
		oSkin:applySkin(TradeskillInfoConfigFrame);
	end
end

function TradeskillInfo:Config_Show()
	ShowUIPanel(TradeskillInfoConfigFrame);
end

function TradeskillInfo:Config_Hide()
	HideUIPanel(TradeskillInfoConfigFrame);
end

function TradeskillInfo:ConfigFrame_OnShow()
	for key, value in pairs(self.options.CheckBoxes) do
		option = getglobal("TradeskillInfo_Option"..value.index);
		text = getglobal("TradeskillInfo_Option"..value.index.."Text");
		if (option) then
			text:SetText(key);
			option.var = value.var;
			option:SetChecked(self.db.profile[value.var]);
			if (value.tooltipText) then
				option.tooltipText = value.tooltipText;
			end
		end
	end

	for key, value in pairs(self.options.ColorSwatches) do
		frame = getglobal("TradeskillInfo_Color"..value.index);
		swatch = getglobal("TradeskillInfo_Color"..value.index.."NormalTexture");
		sColor = self.db.profile[value.var];
		frame.r = sColor.r;
		frame.g = sColor.g;
		frame.b = sColor.b;
		local i = value.index;
		local k = value.var;
		frame.swatchFunc = function() self:Config_SetColor(i, k) end;
		frame.cancelFunc = function(x) self:Config_CancelColor(i, k, x) end;
		swatch:SetVertexColor(sColor.r,sColor.g,sColor.b);
	end

	--Dropdowns
	for key, value in pairs(self.options.Selections) do
		option1 = getglobal("TradeskillInfo_Selection"..value.index);
		option2 = getglobal("TradeskillInfo_Selection"..value.index.."Label");
		option1.var = value.var;
		option1.lookup = value.table;
		getvalue = self.db.profile[value.var];
		UIDropDownMenu_SetSelectedID(option1, getvalue);
		UIDropDownMenu_SetText(value.table[getvalue], option1);
		option1.tooltipText = value.tooltipText;
		option2:SetText(key);
	end
end

function TradeskillInfo:ConfigFrame_OnHide()
end

function TradeskillInfo:OptionsCheckButtonOnClick()
	self.db.profile[this.var] = this:GetChecked() or false;
end

function TradeskillInfo:OptionsRadioButtonOnClick()
end

----------------------
--change tabs
function TradeskillInfo:ConfigTabClick()
	self:ToggleTab(self.options.Frames[this:GetName()]);
	PlaySound("igCharacterInfoTab");
end

----------------------
--change tabs
function TradeskillInfo:ToggleTab(frameName)
	local key, value
	for key, value in pairs(self.options.Frames) do
		if ( value == frameName ) then
			getglobal(value):Show();
			PanelTemplates_SelectTab(getglobal(key));
			getglobal(key):LockHighlight();
		else
			getglobal(value):Hide();
			PanelTemplates_DeselectTab(getglobal(key));
			getglobal(key):UnlockHighlight();
		end	
	end
end

----------------------
--Open the color selector using show/hide
function TradeskillInfo:OpenColorPicker(button)
	--CloseMenus();
	if ( not button ) then
		button = this;
	end
	ColorPickerFrame.func = button.swatchFunc;
	ColorPickerFrame:SetColorRGB(button.r, button.g, button.b);
	ColorPickerFrame.previousValues = {r = button.r, g = button.g, b = button.b, opacity = button.opacity};
	ColorPickerFrame.cancelFunc = button.cancelFunc;
	ColorPickerFrame:Show();
end

----------------------
--Sets the colors of the config from a color swatch
function TradeskillInfo:Config_SetColor(index,key)
	local r,g,b = ColorPickerFrame:GetColorRGB();
	local color = self.db.profile[key];
	local swatch = getglobal("TradeskillInfo_Color"..index.."NormalTexture");
	local frame = getglobal("TradeskillInfo_Color"..index);
	swatch:SetVertexColor(r,g,b);
	frame.r, frame.g, frame.b = r,g,b;
	color.r, color.g, color.b = r,g,b;
end
----------------------
-- Cancels the color selection
function TradeskillInfo:Config_CancelColor(index, key, prev)
	local r,g,b = prev.r, prev.g, prev.b;
	local color = self.db.profile[key];
	local swatch = getglobal("TradeskillInfo_Color"..index.."NormalTexture");
	local frame = getglobal("TradeskillInfo_Color"..index);
	swatch:SetVertexColor(r, g, b);
	frame.r, frame.g, frame.b = r,g,b;
	color.r, color.g, color.b = r,g,b;
end

---------------------
--Init a Dropdown
function TradeskillInfo:DropDown_Initialize()
	local info = {};
	for index, value in pairs(TradeskillInfo.options.Selections) do
		if (this:GetName() == "TradeskillInfo_Selection"..value.index.."Button") then
			for key, name in pairs(value.table) do
				info = {};
				info.text = name;
				info.func = function(x) self:DropDown_OnClick(x) end;
				info.arg1 = value.index;
				UIDropDownMenu_AddButton(info);
			end
			break;
		end
	end
end

---------------------
-- Dropdown Onclick
function TradeskillInfo:DropDown_OnClick(list)
	local ddl = getglobal("TradeskillInfo_Selection"..list);
	UIDropDownMenu_SetSelectedID(ddl, this:GetID());
--	if (ddl.SCTTable) then
--		self.db.profile[SCT.FRAMES_DATA_TABLE][ddl.SCTTable][ddl.SCTVar] = this:GetID();
--	else
		self.db.profile[ddl.var] = this:GetID();
--	end
end

